const methods = {
	escape: function (str) {
		str = str || '';
		var arrEntities = {'lt': '<', 'gt': '>', 'nbsp': ' ', 'amp': '&', 'quot': '"'};
		return str.replace(/&(lt|gt|nbsp|amp|quot);/ig, function (all, t) {
			return arrEntities[t];
		});
	},
	parseSelected: (that) => {
		return that.selected.map((v) => {
			const text = methods.escape(that.find(`option[value=${v}]`).html());
			return {text: text, value: v};
		});
	},
	heightAdaptor: (that, includeSelected = true) => {
		//处理高度问题
		//此处可以把适配过的数据存起来
		let baseHeight, padding, baseLineHeight;
		if (that.size.baseHeight && that.size.padding && that.size.baseLineHeight) {
			baseHeight = that.size.baseHeight;
			padding = that.size.padding;
			baseLineHeight = that.size.baseLineHeight;
		} else {
			const tmpJDom = that.shower.find('.selected_item');
			baseHeight = that.shower.innerHeight();
			baseLineHeight = tmpJDom.outerHeight();
			padding = (baseHeight - baseLineHeight) / 2;
			that.size.baseHeight = baseHeight;
			that.size.baseLineHeight = baseLineHeight;
			that.size.padding = padding;
		}

		//该方法也可以只适配选项，不对选中项进行重复适配
		if (includeSelected) {
			//行内块元素有3像素底边距,最后下边距要 -3 。为了防止边距计算小于3减出负值，这里限制最小边距为3px
			padding = padding < 3 ? 3 : padding;
			that.shower.find('.selected_container').css('padding', `${padding}px ${padding}px ${padding - 3}px`);
			//处理关闭按钮大小
			//图标缩放比例
			const iconScale = 1.6;
			that.shower.find('.close').css({
				width: baseLineHeight,
				//减去2像素边框
				height: baseLineHeight - 2,
				backgroundSize: baseLineHeight / iconScale
			});
		}
		//选项和搜索框高度要跟shower保持一致
		that.downer.find('li').css({
			padding: padding,
			minHeight:baseHeight
		});
	},
	getDataFromJDom: (JDom) => {
		return JDom.find('.selector_text').data('value').toString();
	},
	addData: (that, data, useJDom = false) => {
		data = useJDom ? methods.getDataFromJDom(data) : data;
		that.selected.push(data);
		methods.dataCallBack(that);
	},
	removeData: (that, data, useJDom = false) => {
		data = useJDom ? methods.getDataFromJDom(data) : data.toString();
		that.selected.splice(that.selected.indexOf(data), 1);
		methods.dataCallBack(that);
	},
	clearData: (that, callBack = true) => {
		that.selected = [];
		if (callBack)
			methods.dataCallBack(that);
	},
	dataCallBack: (that) => {
		//同步select标签的value
		that.val(that.selected);
		if (that.options.onChange) {
			//防止选项回调函数中误改组件内数据
			that.options.onChange(JSON.parse(JSON.stringify(that.selected)));
		}
	},
	resetTheme: (that) => {
		if (!that.options.colors) return;
		const themeColors = that.options.colors;
		const theme = {
			backgroundColor: themeColors.background,
			color: themeColors.front
		};
		that.selector.find('.backgroundColor').css(theme);
		that.selector.css(theme);
		that.selector.find('.selected').css({
			color: themeColors.selectedFront,
			backgroundColor: themeColors.selectedBackground
		});
	}
};

export default methods;