const path = require('path');
const webpack = require('webpack');
const html = require('html-webpack-plugin');
const env = process.env.type;

let entry, devtool, outputPath, plugins = [];
if (decodeURIComponent(env) === 'development') {
	entry = './src/entry.js';
	devtool = 'eval-source-map';
	outputPath = path.resolve(__dirname, 'dist');
	plugins = [
		new html({
			template: path.resolve(__dirname, './src/index.html'),
			minify: {
				collapseWhitespace: true
			}
		}),
		new webpack.ProvidePlugin({
			$: 'jquery'
		})
	];
} else {
	entry = './src/entryProd.js';
	outputPath = path.resolve(__dirname, 'dist/prod');;
}

module.exports = {
	// 调试source-map
	devtool: devtool,
	//入口文件的配置项
	entry: {
		entry: entry
	},
	//出口文件的配置项
	output: {
		//打包的路径文职
		path: outputPath,
		//打包的文件名称
		filename: 'jq-selector.js'
	},
	//模块：例如解读CSS,图片如何转换，压缩
	module: {
		rules: [
			{
				test: /\.less$/,
				use: [
					'style-loader',
					{loader: 'css-loader', options: {importLoaders: 1}},
					'less-loader'
				]
			},
			{
				test: /\.css$/,
				use: ['style-loader', 'css-loader']
			},
			{
				test: /\.(png|jpg|gif)/,
				use: [{
					loader: 'url-loader',
					options: {
						limit: 500000
					}
				}]
			}, {
				test: /\.art.html$/,
				use: [{
					loader: 'art-template-loader',
					options: {}
				}]
			}
		]
	},
	//插件，用于生产模版和各项功能
	plugins: plugins,
	//配置webpack开发服务功能
	devServer: {
		//设置基本目录结构
		contentBase: path.resolve(__dirname, 'dist'),
		//服务器的IP地址，可以使用IP也可以使用localhost
		host: 'localhost',
		//服务端压缩是否开启
		compress: false,
		//配置服务端口号
		port: 1717
	}
};